////////////////////////////////////////////////////////////////////////////
//   Copyright 2013  Teradici Corporation
//
//   This program is free software; you can redistribute it and/or modify it
//   under the terms and conditions of the GNU General Public License,
//   version 2, as published by the Free Software Foundation.
//
////////////////////////////////////////////////////////////////////////////
/// \file
/// \brief
///     Byte stream definitions
///
///     This library abstracts a user buffer into a byte stream.  At the
///     expense of performance, this library helps clean up user interfaces
///     that have buffer requirements (e.g. user doesn't have to pass
///     around buf/buf_len pairs, but instead pass a byte stream struct).
//
////////////////////////////////////////////////////////////////////////////

#pragma once

// ---- Include Files -------------------------------------------------------

// ---- Constants and Types -------------------------------------------------

// --------------------------------------------------------------------------
//  sTERA_BSTREAM_CBLK
///     Byte stream control block
//
//  Description:
///     This structure defines the byte stream control block.
//
typedef struct
{
    UINT8   *buf;                       ///< pointer to start of user buffer
    UINT32   buf_size;                  ///< size of user buffer in bytes
    UINT32   offset;                    ///< current byte offset into buffer
} sTERA_BSTREAM_CBLK;

// ---- Variable Externs ----------------------------------------------------

// ---- Function Prototypes -------------------------------------------------

extern void tera_bstream_init(
    sTERA_BSTREAM_CBLK  *cb,
    UINT8               *buf,
    UINT32               buf_size
    );

extern void tera_bstream_set_curpos(
    sTERA_BSTREAM_CBLK     *cb,
    UINT32                  cur_pos
    );

extern UINT32 tera_bstream_get_curpos(
    sTERA_BSTREAM_CBLK  *cb
    );

extern UINT32 tera_bstream_get_num_left(
    sTERA_BSTREAM_CBLK *cb
    );

extern UINT8 tera_bstream_get8(
    sTERA_BSTREAM_CBLK  *cb
    );

extern UINT16 tera_bstream_get16(
    sTERA_BSTREAM_CBLK *cb
    );

extern UINT32 tera_bstream_get32(
    sTERA_BSTREAM_CBLK *cb
    );

extern void tera_bstream_getraw(
    sTERA_BSTREAM_CBLK *cb,
    UINT32              num_bytes,
    UINT8              *dst
    );

extern void tera_bstream_put8(
    sTERA_BSTREAM_CBLK *buf_cb,
    UINT8               val
    );

extern void tera_bstream_put16(
    sTERA_BSTREAM_CBLK *cb,
    UINT16              val
    );

extern void tera_bstream_put32(
    sTERA_BSTREAM_CBLK *cb,
    UINT32              val
    );

extern void tera_bstream_putraw(
    sTERA_BSTREAM_CBLK  *cb,
    UINT32               num_bytes,
    UINT8               *data
    );


