////////////////////////////////////////////////////////////////////////////
//   Copyright 2013  Teradici Corporation
//
//   This program is free software; you can redistribute it and/or modify it
//   under the terms and conditions of the GNU General Public License,
//   version 2, as published by the Free Software Foundation.
//
////////////////////////////////////////////////////////////////////////////
/// \file
/// \brief
///     PCoIP HCC Device Ioctls
///
///     This file defines the PCoIP Host Control Channel (HCC) device
///     driver ioctls.
///
////////////////////////////////////////////////////////////////////////////

#pragma once

// ---- Include Files -------------------------------------------------------

#include "tera_pcoip_public.h"
#include "tera_pcoip_hcc_apdu.h"

// ---- Constants and Types -------------------------------------------------

//
// Macros to define ioctl codes for different HCC users (the IOCTL bit field
// format is defined in the file tera_pcoip_public.h)
//
#define mTERA_PCOIP_HCC_IOCTL_HMI(cmd) \
    mTERA_PCOIP_HCC_IOCTL(((TERA_PCOIP_HCC_APDU_USER_HMI & 0x7) << 5) | \
                          (cmd & 0x1F))
#define mTERA_PCOIP_HCC_IOCTL_KMP(cmd) \
    mTERA_PCOIP_HCC_IOCTL(((TERA_PCOIP_HCC_APDU_USER_KMP & 0x7) << 5) | \
                          (cmd & 0x1F))
#define mTERA_PCOIP_HCC_IOCTL_IMG(cmd) \
    mTERA_PCOIP_HCC_IOCTL(((TERA_PCOIP_HCC_APDU_USER_IMG & 0x7) << 5) | \
                          (cmd & 0x1F))

//
// HMI ioctls
//
#define TERA_PCOIP_HCC_IOCTL_HMI_SESS_INFO_NOTIFY  mTERA_PCOIP_HCC_IOCTL_HMI(0)
#define TERA_PCOIP_HCC_IOCTL_HMI_AVAIL_CMD         mTERA_PCOIP_HCC_IOCTL_HMI(1)
#define TERA_PCOIP_HCC_IOCTL_HMI_VAR_GET           mTERA_PCOIP_HCC_IOCTL_HMI(2)
#define TERA_PCOIP_HCC_IOCTL_HMI_VAR_SET           mTERA_PCOIP_HCC_IOCTL_HMI(3)
#define TERA_PCOIP_HCC_IOCTL_HMI_LOCAL_VAR_GET     mTERA_PCOIP_HCC_IOCTL_HMI(4)
#define TERA_PCOIP_HCC_IOCTL_HMI_LOCAL_VAR_SET     mTERA_PCOIP_HCC_IOCTL_HMI(5)

//
// KMP ioctls
//
#define TERA_PCOIP_HCC_IOCTL_KMP_HDC_COMM_CTRL     mTERA_PCOIP_HCC_IOCTL_KMP(1)
#define TERA_PCOIP_HCC_IOCTL_KMP_PRI_CTXT_GET      mTERA_PCOIP_HCC_IOCTL_KMP(2)

//
// IMG ioctls
//
#define TERA_PCOIP_HCC_IOCTL_IMG_DISP_TOPO_GET       mTERA_PCOIP_HCC_IOCTL_IMG(0)
#define TERA_PCOIP_HCC_IOCTL_IMG_DISP_TOPO_SEND      mTERA_PCOIP_HCC_IOCTL_IMG(1)
#define TERA_PCOIP_HCC_IOCTL_IMG_ASYNC_DISP_TOPO_GET mTERA_PCOIP_HCC_IOCTL_IMG(2)
#define TERA_PCOIP_HCC_IOCTL_IMG_CACHE_DISP_TOPO_GET mTERA_PCOIP_HCC_IOCTL_IMG(3)
#define TERA_PCOIP_HCC_IOCTL_IMG_CACHE_DISP_TOPO_SET mTERA_PCOIP_HCC_IOCTL_IMG(4)
#define TERA_PCOIP_HCC_IOCTL_IMG_USER_CFG_SET        mTERA_PCOIP_HCC_IOCTL_IMG(5)
#define TERA_PCOIP_HCC_IOCTL_IMG_USER_CFG_REQ_GET    mTERA_PCOIP_HCC_IOCTL_IMG(6)
#define TERA_PCOIP_HCC_IOCTL_IMG_USER_CFG_CACHE_SET  mTERA_PCOIP_HCC_IOCTL_IMG(7)

// ---- Variable Externs ----------------------------------------------------

// ---- Function Prototypes -------------------------------------------------

