////////////////////////////////////////////////////////////////////////////
//   Copyright 2013  Teradici Corporation
//
//   This program is free software; you can redistribute it and/or modify it
//   under the terms and conditions of the GNU General Public License,
//   version 2, as published by the Free Software Foundation.
//
////////////////////////////////////////////////////////////////////////////
/// \file
/// \brief
///     Network Interface Class
///
///     This file defines the network interface class API prototypes and
///     definitions.
///
////////////////////////////////////////////////////////////////////////////

#pragma once

// ---- Include Files -------------------------------------------------------

#include <wx/thread.h>

#include "tera_types.h"

// ---- Constants and Types -------------------------------------------------

#define TERA_NETIF_NAME_MAX_LEN  30  // (Note: MUST be at least 4 chars long)
#define TERA_NETIF_IP_MAX_LEN    40

// --------------------------------------------------------------------------
//  cTERA_DEV
///     Device access
//
//  Description:
///     This class defines a device access object to allow I/O control (ioctl)
///     communication with a device in kernel space. This class simplifies the
///     calling of synchronous and asynchronous ioctls.
///
class cTERA_NETIF
{

public:

    // --- Public Functions -------------------------------------------------

    cTERA_NETIF(void);

    ~cTERA_NETIF(void);

    INT32 if_query(void);

    UINT32 if_count(void);

    INT32 if_by_index(
        UINT32 index,
        char   name[TERA_NETIF_NAME_MAX_LEN],
        char   ip[TERA_NETIF_IP_MAX_LEN],
        UINT8  mac[6]);

protected:

    // ------------------------------------------------------------------------
    //  sNETIF
    ///     Network interface
    //
    //  Description:
    ///     This structure contains all the information of interest for a
    ///     single network interface. This structure supports both IPv4 and
    ///     IPv6 addresses.
    ///
    typedef struct sNETIF_STRUCT
    {
        struct sNETIF_STRUCT *next;             ///< Next pointer

        char  name[TERA_NETIF_NAME_MAX_LEN];    ///< Friend name of interface
        char  ip[TERA_NETIF_IP_MAX_LEN];        ///< IPv4/IPv6 address
        UINT8 mac[6];                           ///< MAC address
    } sNETIF;

    // --- Protected Functions ----------------------------------------------

    void if_list_entry_add(
        sNETIF *entry);

    void if_list_clear(void);

    // --- Protected Variables ----------------------------------------------

    sNETIF *m_if_list;          ///< Network interface list
    UINT32  m_if_list_count;    ///< Network interface list length
    wxMutex m_list_lock;        ///< Internal list lock
}; // cTERA_NETIF

// ---- Variable Externs ----------------------------------------------------

// ---- Function Prototypes -------------------------------------------------

