////////////////////////////////////////////////////////////////////////////
//   Copyright 2013  Teradici Corporation
//
//   This program is free software; you can redistribute it and/or modify it
//   under the terms and conditions of the GNU General Public License,
//   version 2, as published by the Free Software Foundation.
//
////////////////////////////////////////////////////////////////////////////
/// \file
/// \brief
///     PCoIP Host Software Monitor Property Page Class
///
///     This file defines the PCoIP Host Software Monitor property page class.
///
////////////////////////////////////////////////////////////////////////////

#pragma once

// ---- Include Files -------------------------------------------------------

#include "tera_pcoip_agent_gui_res.h"

// ---- Constants and Types -------------------------------------------------

#define MAX_MON_COUNT       4

typedef struct
{
    INT32 width;
    INT32 height;
    INT32 pos_x;
    INT32 pos_y;
    UINT32 mon;
} sSCREEN_INFO;

// --------------------------------------------------------------------------
//  cPCOIP_AGENT_GUI_PROP_MON
///     PCoIP Host Software Monitor property page
//
//  Description:
///     This class defines the PCoIP Host Software Monitor property page.
///     This page shows the monitor configuration of the agent.
///
class cPCOIP_AGENT_GUI_PROP_MON : public cPCOIP_AGENT_GUI_PROP_MON_BASE
{

public:

    // --- Public Functions -------------------------------------------------

    cPCOIP_AGENT_GUI_PROP_MON(
        wxWindow *parent);

    ~cPCOIP_AGENT_GUI_PROP_MON(void);

    int num_client_monitors(void);

    void delete_mon_usr_cfg(void);

    int is_screen_cfg_ok(void);

    int is_screen_cfg_position_ok(void);

    void screen_list_init(
        UINT32 num_screens,
        sSCREEN_INFO *screens);

    UINT32 get_idx_monitor(
        UINT32 mon_num,
        UINT32 *topo_idx);

    void mon_list_init(void);

    // --- Public Variables -------------------------------------------------

protected:

    typedef struct
    {
        wxString name;
        wxString vid;
        wxString pid;
        wxString serial;
        wxString resolution;
    } sMON_INFO;

    // --- Protected Functions ----------------------------------------------

    // Event handlers
    void evt_init_dialog(
        wxInitDialogEvent& evt);

    void evt_apply_btn(
        wxCommandEvent& evt);

    void evt_pg_changed(
        wxPropertyGridEvent& evt);

    // Function overrides

    // Local functions
    int session_is_active(void);

    void dump_dbg_info(void);

    void save_config(void);

    void mon_list_clear(void);

    void screen_list_clear(void);

    void init_from_usr_cfg(void);

    void prop_grid_populate(int ignore_cfg_file);

    void prop_grid_entries_create(void);

    void prop_grid_populate_monitor_info(void);

    void prop_grid_populate_screen_entry(
        UINT32 screen_index);

    void help_btn_setup(int display_help);

    int is_client_mon_connected(
        int index);

    // --- Protected Variables ----------------------------------------------

    UINT32          m_screen_count;               ///< Number of active screens
    UINT32          m_mon_count;                  ///< Number of monitors reported by the FW
    UINT32          m_mon_row_entries;            ///< Number of client monitor rows displayed on the GUI
    int             m_cache_topo_read_err;        ///< flag indicating an error occurred
                                                  ///< reading cached topology
    sSCREEN_INFO    m_screen_list[MAX_MON_COUNT]; ///< List of screens
    sMON_INFO       m_mon_list[MAX_MON_COUNT];    ///< List of monitors

    DECLARE_EVENT_TABLE()
}; // cPCOIP_AGENT_GUI_PROP_MON

// ---- Variable Externs ----------------------------------------------------

// ---- Function Prototypes -------------------------------------------------

