////////////////////////////////////////////////////////////////////////////
//   Copyright 2013  Teradici Corporation
//
//   This program is free software; you can redistribute it and/or modify it
//   under the terms and conditions of the GNU General Public License,
//   version 2, as published by the Free Software Foundation.
//
////////////////////////////////////////////////////////////////////////////
/// \file
/// \brief
///     PCoIP Host Software Property Sheet Class Implementation
///
///     This file implements the PCoIP Host Software property sheet class.
///
////////////////////////////////////////////////////////////////////////////

// ---- Include Files -------------------------------------------------------

#include <wx/wxprec.h>

#if !defined(WX_PRECOMP)
    #include <wx/wx.h>
#endif

#include <wx/bookctrl.h>
#include <wx/artprov.h>

#include <wx/toolbook.h>

#include "tera_log.h"
#include "tera_types.h"
#include "tera_pcoip_agent_internal.h"
#include "tera_pcoip_agent_gui_prop.h"
#include "tera_pcoip_agent_gui_prop_feat.h"
#include "tera_pcoip_agent_gui_prop_net.h"
#include "tera_pcoip_agent_gui_prop_stat.h"
#include "tera_pcoip_agent_gui_prop_mon.h"
#include "tera_pcoip_agent_gui_prop_img.h"
#include "tera_pcoip_agent_gui_prop_about.h"
#include "tera_pcoip_agent_icon_res.xpm"

// ---- Global Variables ----------------------------------------------------

// ---- Private Constants and Types -----------------------------------------

BEGIN_EVENT_TABLE(cPCOIP_AGENT_GUI_PROP, wxPropertySheetDialog)
    EVT_INIT_DIALOG(cPCOIP_AGENT_GUI_PROP::evt_init_dialog)
    EVT_CLOSE(cPCOIP_AGENT_GUI_PROP::evt_close)
END_EVENT_TABLE()

// ---- Local Variables -----------------------------------------------------

// ---- Local Function Prototypes -------------------------------------------

void cPCOIP_AGENT_GUI_PROP::evt_init_dialog(
    wxInitDialogEvent& evt
    )
{
    mTERA_LOG_DBG("start - cPCOIP_AGENT_GUI_PROP");

    // Initialize each of the property pages
    m_feat_page->InitDialog();
    m_net_page->InitDialog();
    m_stat_page->InitDialog();
    m_mon_page->InitDialog();
    m_img_page->InitDialog();
    m_about_page->InitDialog();

    evt.Skip();

    mTERA_LOG_DBG("end - cPCOIP_AGENT_GUI_PROP");
} // cPCOIP_AGENT_GUI_PROP::evt_init_dialog()

void cPCOIP_AGENT_GUI_PROP::evt_close(
    wxCloseEvent& evt
    )
{
    mTERA_LOG_DBG("start - cPCOIP_AGENT_GUI_PROP");

    // Close each of the property pages
    m_feat_page->Close();
    m_net_page->Close();
    m_stat_page->Close();
    m_mon_page->Close();
    m_img_page->Close();
    m_about_page->Close();

    evt.Skip();

    mTERA_LOG_DBG("end - cPCOIP_AGENT_GUI_PROP");
} // cPCOIP_AGENT_GUI_PROP::evt_close()

// --------------------------------------------------------------------------
//  cPCOIP_AGENT_GUI_PROP::cPCOIP_AGENT_GUI_PROP
///     Constructor
//
//  Description:
///     This is the PCoIP Host Software property sheet class constructor. This
///     function initializes the memeber data variables, adds the property
///     pages, and hides the HELP button.
///
/// \return
///     None
///
cPCOIP_AGENT_GUI_PROP::cPCOIP_AGENT_GUI_PROP(
    wxWindow *parent
    )
{
    mTERA_LOG_DBG("start");

    wxBookCtrlBase *book_ctrl;

    SetSheetStyle(wxPROPSHEET_NOTEBOOK); // Default

    Create(parent, wxID_ANY, _("PCoIP Host Software Settings"), wxDefaultPosition,
           wxDefaultSize, wxDEFAULT_DIALOG_STYLE | wxMINIMIZE_BOX | wxRESIZE_BORDER);

    book_ctrl = GetBookCtrl();

    // Create the property pages
    m_feat_page = new cPCOIP_AGENT_GUI_PROP_FEAT(book_ctrl);
    m_net_page = new cPCOIP_AGENT_GUI_PROP_NET(book_ctrl);
    m_stat_page = new cPCOIP_AGENT_GUI_PROP_STAT(book_ctrl);
    m_mon_page = new cPCOIP_AGENT_GUI_PROP_MON(book_ctrl);
    m_img_page = new cPCOIP_AGENT_GUI_PROP_IMG(book_ctrl);
    m_about_page = new cPCOIP_AGENT_GUI_PROP_ABOUT(book_ctrl);

    // Add the pages to the book control
    book_ctrl->AddPage(m_feat_page, _("Features"), true);
    book_ctrl->AddPage(m_net_page, _("Net"), false);
    book_ctrl->AddPage(m_stat_page, _("Stats"), false);
    book_ctrl->AddPage(m_mon_page, _("Monitors"), false);
    book_ctrl->AddPage(m_img_page, _("Image"), false);
    book_ctrl->AddPage(m_about_page, _("About"), false);

    LayoutDialog();

    SetIcon(wxICON(IDI_LOGO_16));

    mTERA_LOG_DBG("end");
} // cPCOIP_AGENT_GUI_PROP::cPCOIP_AGENT_GUI_PROP()

cPCOIP_AGENT_GUI_PROP::~cPCOIP_AGENT_GUI_PROP(void)
{
    mTERA_LOG_DBG("start");
    mTERA_LOG_DBG("end");
} // cPCOIP_AGENT_GUI_PROP::~cPCOIP_AGENT_GUI_PROP()

